package VMOMI::HostConfigChangeOperation;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
